diff src/share/vm/adlc/output_c.cpp @ 4114:6729bbc1fcd6

7003454: order constants in constant table by number of references in code Reviewed-by: kvn, never, bdelsart
author twisti
date Wed, 16 Nov 2011 01:39:50 -0800
parents 11211f7cb5a0
children db2e64ca2d5a
line wrap: on
line diff
--- a/src/share/vm/adlc/output_c.cpp	Mon Nov 14 18:38:03 2011 -0800
+++ b/src/share/vm/adlc/output_c.cpp	Wed Nov 16 01:39:50 2011 -0800
@@ -2585,9 +2585,9 @@
   // Output instruction's emit prototype
   fprintf(fp, "void %sNode::eval_constant(Compile* C) {\n", inst._ident);
 
   // For ideal jump nodes, allocate a jump table.
   if (inst.is_ideal_jump()) {
-    fprintf(fp, "  _constant = C->constant_table().allocate_jump_table(this);\n");
+    fprintf(fp, "  _constant = C->constant_table().add_jump_table(this);\n");
   }
 
   // If user did not define an encode section,
@@ -2585,9 +2585,9 @@
   fprintf(fp, "void %sNode::eval_constant(Compile* C) {\n", inst._ident);
 
-  // For ideal jump nodes, allocate a jump table.
+  // For ideal jump nodes, add a jump-table entry.
   if (inst.is_ideal_jump()) {